@@ -28,18 +28,18 @@ def load_config(filename="config.yml"):
 
 def is_valid_ipv6_address(ip):
     try:
-        addr = IPv6Address(ip)
+        IPv6Address(ip)
     except ValueError:
         return False
-    return addr.is_global
+    return True
 
 
 def is_valid_ipv4_address(ip):
     try:
-        addr = IPv4Address(ip)
+        IPv4Address(ip)
     except ValueError:
         return False
-    return addr.is_global
+    return True
 
 
 def is_valid_ip_address(ip):
